@@ -106,7 +106,7 @@ class ProblemReport(UserDict):
         # keeps track of keys which were added since the last ctor or load()
         self.old_keys = set()
 
-    def load(self, file, binary=True):
+    def load(self, file, binary=True, key_filter=None):
         '''Initialize problem report from a file-like object.
 
         If binary is False, binary data is not loaded; the dictionary key is
@@ -119,6 +119,8 @@ class ProblemReport(UserDict):
 
         file needs to be opened in binary mode.
 
+        If key_filter is given, only those keys will be loaded.
+
         Files are in RFC822 format, but with case sensitive keys.
         '''
         self._assert_bin_mode(file)
@@ -127,6 +129,10 @@ class ProblemReport(UserDict):
         value = None
         b64_block = False
         bd = None
+        if key_filter:
+            remaining_keys = set(key_filter)
+        else:
+            remaining_keys = None
         for line in file:
             # continuation line
             if line.startswith(b' '):
@@ -170,7 +176,18 @@ class ProblemReport(UserDict):
                     bd = None
                 if key:
                     assert value is not None
-                    self.data[key] = self._try_unicode(value)
+                    if remaining_keys is not None:
+                        try:
+                            remaining_keys.remove(key)
+                            self.data[key] = self._try_unicode(value)
+                            if not remaining_keys:
+                                key = None
+                                break
+                        except KeyError:
+                            pass
+                    else:
+                        self.data[key] = self._try_unicode(value)
+
                 (key, value) = line.split(b':', 1)
                 if not _python2:
                     key = key.decode('ASCII')
