@@ -51,49 +51,41 @@ class T(unittest.TestCase):
         self.assertTrue(bad_ko.name in nonfree)
 
     def test_attach_dmesg(self):
-        '''attach_dmesg() does not overwrite already existing data'''
+        '''attach_dmesg()'''
 
         report = {}
 
         apport.hookutils.attach_dmesg(report)
-        self.assertTrue(report['BootDmesg'].startswith('['))
-        self.assertTrue(len(report['BootDmesg']) > 500)
+        self.assertTrue(len(report['CurrentDmesg']) > 500)
         self.assertTrue(report['CurrentDmesg'].startswith('['))
 
     def test_dmesg_overwrite(self):
         '''attach_dmesg() does not overwrite already existing data'''
 
-        report = {'BootDmesg': 'existingboot'}
+        report = {'CurrentDmesg': 'existingcurrent'}
 
         apport.hookutils.attach_dmesg(report)
-        self.assertEqual(report['BootDmesg'][:50], 'existingboot')
-        self.assertTrue(report['CurrentDmesg'].startswith('['))
-
-        report = {'BootDmesg': 'existingboot', 'CurrentDmesg': 'existingcurrent'}
-
-        apport.hookutils.attach_dmesg(report)
-        self.assertEqual(report['BootDmesg'], 'existingboot')
         self.assertEqual(report['CurrentDmesg'], 'existingcurrent')
 
     def test_attach_file(self):
         '''attach_file()'''
 
-        with open('/etc/motd') as f:
-            motd_contents = f.read().strip()
+        with open('/etc/passwd') as f:
+            passwd_contents = f.read().strip()
         with open('/etc/issue') as f:
             issue_contents = f.read().strip()
 
         # default key name
         report = {}
-        apport.hookutils.attach_file(report, '/etc/motd')
-        self.assertEqual(list(report), ['.etc.motd'])
-        self.assertEqual(report['.etc.motd'], motd_contents)
+        apport.hookutils.attach_file(report, '/etc/passwd')
+        self.assertEqual(list(report), ['.etc.passwd'])
+        self.assertEqual(report['.etc.passwd'], passwd_contents)
 
         # custom key name
         report = {}
-        apport.hookutils.attach_file(report, '/etc/motd', 'Motd')
-        self.assertEqual(list(report), ['Motd'])
-        self.assertEqual(report['Motd'], motd_contents)
+        apport.hookutils.attach_file(report, '/etc/passwd', 'Passwd')
+        self.assertEqual(list(report), ['Passwd'])
+        self.assertEqual(report['Passwd'], passwd_contents)
 
         # nonexisting file
         report = {}
@@ -103,15 +95,15 @@ class T(unittest.TestCase):
 
         # existing key
         report = {}
-        apport.hookutils.attach_file(report, '/etc/motd')
-        apport.hookutils.attach_file(report, '/etc/motd')
-        self.assertEqual(list(report), ['.etc.motd'])
-        self.assertEqual(report['.etc.motd'], motd_contents)
+        apport.hookutils.attach_file(report, '/etc/passwd')
+        apport.hookutils.attach_file(report, '/etc/passwd')
+        self.assertEqual(list(report), ['.etc.passwd'])
+        self.assertEqual(report['.etc.passwd'], passwd_contents)
 
-        apport.hookutils.attach_file(report, '/etc/issue', '.etc.motd', overwrite=False)
-        self.assertEqual(sorted(report.keys()), ['.etc.motd', '.etc.motd_'])
-        self.assertEqual(report['.etc.motd'], motd_contents)
-        self.assertEqual(report['.etc.motd_'], issue_contents)
+        apport.hookutils.attach_file(report, '/etc/issue', '.etc.passwd', overwrite=False)
+        self.assertEqual(sorted(report.keys()), ['.etc.passwd', '.etc.passwd_'])
+        self.assertEqual(report['.etc.passwd'], passwd_contents)
+        self.assertEqual(report['.etc.passwd_'], issue_contents)
 
     def test_attach_file_binary(self):
         '''attach_file() for binary files'''
@@ -130,30 +122,30 @@ class T(unittest.TestCase):
     def test_attach_file_if_exists(self):
         '''attach_file_if_exists()'''
 
-        with open('/etc/motd') as f:
-            motd_contents = f.read().strip()
+        with open('/etc/passwd') as f:
+            passwd_contents = f.read().strip()
 
         # default key name
         report = {}
-        apport.hookutils.attach_file_if_exists(report, '/etc/motd')
-        self.assertEqual(list(report), ['.etc.motd'])
-        self.assertEqual(report['.etc.motd'], motd_contents)
+        apport.hookutils.attach_file_if_exists(report, '/etc/passwd')
+        self.assertEqual(list(report), ['.etc.passwd'])
+        self.assertEqual(report['.etc.passwd'], passwd_contents)
 
         # custom key name
         report = {}
-        apport.hookutils.attach_file_if_exists(report, '/etc/motd', 'Motd')
-        self.assertEqual(list(report), ['Motd'])
-        self.assertEqual(report['Motd'], motd_contents)
+        apport.hookutils.attach_file_if_exists(report, '/etc/passwd', 'Passwd')
+        self.assertEqual(list(report), ['Passwd'])
+        self.assertEqual(report['Passwd'], passwd_contents)
 
         # nonexisting file
         report = {}
         apport.hookutils.attach_file_if_exists(report, '/nonexisting')
         self.assertEqual(list(report), [])
 
-    def test_recent_logfile(self):
-        '''recent_logfile'''
+    def test_recent_syslog(self):
+        '''recent_syslog'''
 
-        self.assertEqual(apport.hookutils.recent_logfile('/nonexisting', re.compile('.')), '')
+        self.assertEqual(apport.hookutils.recent_syslog(re.compile('.'), path='/nonexisting'), '')
         self.assertEqual(apport.hookutils.recent_syslog(re.compile('ThisCantPossiblyHitAnything')), '')
         self.assertNotEqual(len(apport.hookutils.recent_syslog(re.compile('.'))), 0)
 
@@ -288,8 +280,8 @@ class T(unittest.TestCase):
         apport.hookutils.attach_mac_events(report, '/usr/sbin/cupsd')
         self.assertEqual(report['Tags'], 'apparmor')
 
-    def test_recent_logfile_overflow(self):
-        '''recent_logfile on a huge file'''
+    def test_recent_syslog_overflow(self):
+        '''recent_syslog on a huge file'''
 
         log = os.path.join(self.workdir, 'syslog')
         with open(log, 'w') as f:
@@ -299,7 +291,7 @@ class T(unittest.TestCase):
                 lines -= 1
 
         mem_before = self._get_mem_usage()
-        data = apport.hookutils.recent_logfile(log, re.compile('kernel'))
+        data = apport.hookutils.recent_syslog(re.compile('kernel'), path=log)
         mem_after = self._get_mem_usage()
         delta_kb = mem_after - mem_before
         sys.stderr.write('[Δ %i kB] ' % delta_kb)
@@ -309,7 +301,7 @@ class T(unittest.TestCase):
         self.assertGreater(len(data), 100000)
         self.assertLess(len(data), 1000000)
 
-    @unittest.skipIf(apport.hookutils.apport.hookutils.in_session_of_problem(apport.Report()) is None, 'no ConsoleKit session')
+    @unittest.skipIf(apport.hookutils.apport.hookutils.in_session_of_problem(apport.Report()) is None, 'no logind session')
     def test_in_session_of_problem(self):
         '''in_session_of_problem()'''
 
@@ -412,6 +404,8 @@ GdkPixbuf-CRITICAL **: gdk_pixbuf_scale_simple: another standard glib assertion
         apport.hookutils.attach_conffiles(report, 'nonexisting')
         apport.hookutils.attach_upstart_overrides(report, 'apport')
         apport.hookutils.attach_upstart_overrides(report, 'nonexisting')
+        apport.hookutils.attach_upstart_logs(report, 'apport')
+        apport.hookutils.attach_upstart_logs(report, 'nonexisting')
         apport.hookutils.attach_default_grub(report)
 
     def test_command_output(self):
